@@ -135,7 +135,7 @@ c           boost to target rest system
 
       write(0, *) 'Active int. model=',ActiveMdl
       write(0, *) ' equiv. lab E=', plab.fm.p(4)
-      write(*, '(a)') '#  mulsubKEdir   '
+      write(*, '(a)') '#  mulsubKEdir  user '
       write(*, '(a)') '#--------------------------------'
       end
       subroutine outresul(a, ntp)
@@ -162,9 +162,9 @@ c           boost to target rest system
          wx = a(i).fm.p(1)/p               
          wy = a(i).fm.p(2)/p               
          wz = a(i).fm.p(3)/p               
-         write(*,'(3i3,g14.5,3f17.13)')
+         write(*,'(3i3,g14.5,3f17.13, i5)')
      *        a(i).code, a(i).subcode, a(i).charge,
-     *        a(i).fm.p(4)-a(i).mass, wx, wy, wz
+     *        a(i).fm.p(4)-a(i).mass, wx, wy, wz, j
       enddo
       if(ntp .gt. 0 .or. outzero .eq. 0) then
          write(*, *) 
