@@ -50,9 +50,12 @@ c         convert pos/w into  l.c
         if(aTrack.cn .le. Det.nct ) then
 
            call epw2l(aTrack.cn, aTrack.pos, aTrack.pos)
-           call epw2ld(aTrack.cn, aTrack.w,  aTrack.w)
+cc           call epw2ld(aTrack.cn, aTrack.w,  aTrack.w)
+           call epw2ldm(aTrack.cn, aTrack.w,  aTrack.w, aTrack.p)
            call eppush(aTrack)
         else
+           write(0,*) ' current comp. #=',aTrack.cn,
+     *      ' total comp.#=', Det.nct
            call
      *     cerrorMsg(' epputTrack: ptcl is not in detector', 0)
         endif
@@ -77,7 +80,8 @@ c              and  set it in aTrack.cn
 c         convert pos/w into  l.c
         if(aTrack.cn .le. Det.nct ) then
            call epw2l(aTrack.cn, aTrack.pos, aTrack.pos)
-           call epw2ld(aTrack.cn, aTrack.w,  aTrack.w)
+c           call epw2ld(aTrack.cn, aTrack.w,  aTrack.w)
+           call epw2ldm(aTrack.cn, aTrack.w,  aTrack.w, aTrack.p)
            write(io) aTrack
            StackDisk = io
         else
@@ -107,7 +111,7 @@ c                  -1:  no more ptcl
 c
        record /epTrack/ aTrack
        integer icon
-       pathInB = 0.
+
  10    continue
 c         do 876 until (ok)
        if(Stack_pos .gt. 0) then
@@ -127,13 +131,20 @@ c              do business when a new component appear
           if(icon .ne. 0) goto 10
 
        else
-          if(StackDisk .gt. 0) then
-             read(StackDisk, end=100) aTrack
+          if(StackDisk .ne. 0) then
+             if(StackDisk .gt. 0) then
+                rewind StackDisk
+                StackDisk=-StackDisk
+             endif
+             read(-StackDisk, end=100) aTrack
              call eppush(aTrack)
              goto 10
           endif
  100      continue
-          StackDisk = 0
+          if(StackDisk .ne. 0) then
+             rewind -StackDisk
+             StackDisk = 0
+          endif
           icon=-1
        endif
  876    continue
