@@ -72,6 +72,8 @@ c              incident energy sampling. initializaiton
            Inpdir = 0
            Inperg  = 0
            Inptime = 0
+           Inpdisk = 0
+           Inpuser = 0
            call ciniSPrim(PrimaryFile)
 
         endif
@@ -126,7 +128,7 @@ c         ---------------- Error -----------------
 #include  "ZsepManager.h"
        character(*) file
        character*50  inpcond
-       integer klena,icon
+       integer klena,icon, loc
 
        open(Ioprim, file=file(1:klena(file) ))
        read(Ioprim, '(a)')  inpcond
@@ -164,6 +166,21 @@ c         ---------------- Error -----------------
        else
           Inptime = 0
        endif
+
+       loc = index(inpcond, "user")
+       if( loc .gt. 0) then
+          Inpuser = 1
+       else
+          Inpuser = 0
+       endif
+
+       loc = index(inpcond, "disk")
+       if( loc .gt. 0) then
+          read(inpcond(loc+4:loc+5), *) Inpdisk
+       else
+          Inpdisk = 0
+       endif
+
        call cskipComment(Ioprim, icon)
        if(icon .ne. 0) then
           call cerrorMsg("Primary file has no #----- line", 0)
@@ -239,6 +256,10 @@ c              the acuracy of input data may not be enough
           read( field(fc), *)   aTrack.t 
           aTrack.t = aTrack.t*29.98d0    ! cm (t is nsec)
        endif
+       if( Inpuser .gt. 0 ) then
+          fc = fc + 1
+          read( field(fc), *)   aTrack.user
+       endif
 c         check number of field; some redandant field may exist at the last part, so
 c         nf many not be equal to fc. but must be nf >= fc
        if(nf .lt.  fc) then
@@ -465,7 +486,11 @@ c               fix others
 
       call sfixo(aTrack)
 c               set them
-      call epputTrack(aTrack)
+      if(Inpdisk .eq. 0) then
+         call epputTrack(aTrack)
+      else
+         call epputTrk2(Inpdisk, aTrack)
+      endif
       InciTrack = aTrack
       return
 c      *****************
